==> projen-0.45.3-sources.jar: io/github/cdklabs/projen/GitpodPrebuilds.java <==
package io.github.cdklabs.projen;

/**
 * (experimental) Configure the Gitpod App for prebuilds.
 * <p>
 * Currently only GitHub is supported.
 * <p>
 * @see https://www.gitpod.io/docs/prebuilds/
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.47.0 (build 86d2c33)", date = "2021-12-20T00:39:28.401Z")
@software.amazon.jsii.Jsii(module = io.github.cdklabs.projen.$Module.class, fqn = "projen.GitpodPrebuilds")
@software.amazon.jsii.Jsii.Proxy(GitpodPrebuilds.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
public interface GitpodPrebuilds extends software.amazon.jsii.JsiiSerializable {

    /**
     * (experimental) Add a "Review in Gitpod" button to the pull request's description.
     * <p>
     * Default: false
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    default @org.jetbrains.annotations.Nullable java.lang.Boolean getAddBadge() {
        return null;
    }

    /**
     * (experimental) Add a check to pull requests.
     * <p>
     * Default: true
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    default @org.jetbrains.annotations.Nullable java.lang.Boolean getAddCheck() {
        return null;
    }

    /**
     * (experimental) Add a "Review in Gitpod" button as a comment to pull requests.
     * <p>
     * Default: false
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    default @org.jetbrains.annotations.Nullable java.lang.Boolean getAddComment() {
        return null;
    }

    /**
     * (experimental) Add a label once the prebuild is ready to pull requests.
     * <p>
     * Default: false
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    default @org.jetbrains.annotations.Nullable java.lang.Boolean getAddLabel() {
        return null;
    }

    /**
     * (experimental) Enable for all branches in this repo.
     * <p>
     * Default: false
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    default @org.jetbrains.annotations.Nullable java.lang.Boolean getBranches() {
        return null;
    }

    /**
     * (experimental) Enable for the master/default branch.
     * <p>
     * Default: true
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    default @org.jetbrains.annotations.Nullable java.lang.Boolean getMaster() {
        return null;
    }

    /**
     * (experimental) Enable for pull requests coming from this repo.
     * <p>
     * Default: true
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    default @org.jetbrains.annotations.Nullable java.lang.Boolean getPullRequests() {
        return null;
    }

    /**
     * (experimental) Enable for pull requests coming from forks.
     * <p>
     * Default: false
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    default @org.jetbrains.annotations.Nullable java.lang.Boolean getPullRequestsFromForks() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link GitpodPrebuilds}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link GitpodPrebuilds}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static final class Builder implements software.amazon.jsii.Builder<GitpodPrebuilds> {
        java.lang.Boolean addBadge;
        java.lang.Boolean addCheck;
        java.lang.Boolean addComment;
        java.lang.Boolean addLabel;
        java.lang.Boolean branches;
        java.lang.Boolean master;
        java.lang.Boolean pullRequests;
        java.lang.Boolean pullRequestsFromForks;

        /**
         * Sets the value of {@link GitpodPrebuilds#getAddBadge}
         * @param addBadge Add a "Review in Gitpod" button to the pull request's description.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder addBadge(java.lang.Boolean addBadge) {
            this.addBadge = addBadge;
            return this;
        }

        /**
         * Sets the value of {@link GitpodPrebuilds#getAddCheck}
         * @param addCheck Add a check to pull requests.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder addCheck(java.lang.Boolean addCheck) {
            this.addCheck = addCheck;
            return this;
        }

        /**
         * Sets the value of {@link GitpodPrebuilds#getAddComment}
         * @param addComment Add a "Review in Gitpod" button as a comment to pull requests.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder addComment(java.lang.Boolean addComment) {
            this.addComment = addComment;
            return this;
        }

        /**
         * Sets the value of {@link GitpodPrebuilds#getAddLabel}
         * @param addLabel Add a label once the prebuild is ready to pull requests.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder addLabel(java.lang.Boolean addLabel) {
            this.addLabel = addLabel;
            return this;
        }

        /**
         * Sets the value of {@link GitpodPrebuilds#getBranches}
         * @param branches Enable for all branches in this repo.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder branches(java.lang.Boolean branches) {
            this.branches = branches;
            return this;
        }

        /**
         * Sets the value of {@link GitpodPrebuilds#getMaster}
         * @param master Enable for the master/default branch.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder master(java.lang.Boolean master) {
            this.master = master;
            return this;
        }

        /**
         * Sets the value of {@link GitpodPrebuilds#getPullRequests}
         * @param pullRequests Enable for pull requests coming from this repo.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder pullRequests(java.lang.Boolean pullRequests) {
            this.pullRequests = pullRequests;
            return this;
        }

        /**
         * Sets the value of {@link GitpodPrebuilds#getPullRequestsFromForks}
         * @param pullRequestsFromForks Enable for pull requests coming from forks.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder pullRequestsFromForks(java.lang.Boolean pullRequestsFromForks) {
            this.pullRequestsFromForks = pullRequestsFromForks;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link GitpodPrebuilds}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @Override
        public GitpodPrebuilds build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link GitpodPrebuilds}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements GitpodPrebuilds {
        private final java.lang.Boolean addBadge;
        private final java.lang.Boolean addCheck;
        private final java.lang.Boolean addComment;
        private final java.lang.Boolean addLabel;
        private final java.lang.Boolean branches;
        private final java.lang.Boolean master;
        private final java.lang.Boolean pullRequests;
        private final java.lang.Boolean pullRequestsFromForks;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.addBadge = software.amazon.jsii.Kernel.get(this, "addBadge", software.amazon.jsii.NativeType.forClass(java.lang.Boolean.class));
            this.addCheck = software.amazon.jsii.Kernel.get(this, "addCheck", software.amazon.jsii.NativeType.forClass(java.lang.Boolean.class));
            this.addComment = software.amazon.jsii.Kernel.get(this, "addComment", software.amazon.jsii.NativeType.forClass(java.lang.Boolean.class));
            this.addLabel = software.amazon.jsii.Kernel.get(this, "addLabel", software.amazon.jsii.NativeType.forClass(java.lang.Boolean.class));
            this.branches = software.amazon.jsii.Kernel.get(this, "branches", software.amazon.jsii.NativeType.forClass(java.lang.Boolean.class));
            this.master = software.amazon.jsii.Kernel.get(this, "master", software.amazon.jsii.NativeType.forClass(java.lang.Boolean.class));
            this.pullRequests = software.amazon.jsii.Kernel.get(this, "pullRequests", software.amazon.jsii.NativeType.forClass(java.lang.Boolean.class));
            this.pullRequestsFromForks = software.amazon.jsii.Kernel.get(this, "pullRequestsFromForks", software.amazon.jsii.NativeType.forClass(java.lang.Boolean.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.addBadge = builder.addBadge;
            this.addCheck = builder.addCheck;
            this.addComment = builder.addComment;
            this.addLabel = builder.addLabel;
            this.branches = builder.branches;
            this.master = builder.master;
            this.pullRequests = builder.pullRequests;
            this.pullRequestsFromForks = builder.pullRequestsFromForks;
        }

        @Override
        public final java.lang.Boolean getAddBadge() {
            return this.addBadge;
        }

        @Override
        public final java.lang.Boolean getAddCheck() {
            return this.addCheck;
        }

        @Override
        public final java.lang.Boolean getAddComment() {
            return this.addComment;
        }

        @Override
        public final java.lang.Boolean getAddLabel() {
            return this.addLabel;
        }

        @Override
        public final java.lang.Boolean getBranches() {
            return this.branches;
        }

        @Override
        public final java.lang.Boolean getMaster() {
            return this.master;
        }

        @Override
        public final java.lang.Boolean getPullRequests() {
            return this.pullRequests;
        }

        @Override
        public final java.lang.Boolean getPullRequestsFromForks() {
            return this.pullRequestsFromForks;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            if (this.getAddBadge() != null) {
                data.set("addBadge", om.valueToTree(this.getAddBadge()));
            }
            if (this.getAddCheck() != null) {
                data.set("addCheck", om.valueToTree(this.getAddCheck()));
            }
            if (this.getAddComment() != null) {
                data.set("addComment", om.valueToTree(this.getAddComment()));
            }
            if (this.getAddLabel() != null) {
                data.set("addLabel", om.valueToTree(this.getAddLabel()));
            }
            if (this.getBranches() != null) {
                data.set("branches", om.valueToTree(this.getBranches()));
            }
            if (this.getMaster() != null) {
                data.set("master", om.valueToTree(this.getMaster()));
            }
            if (this.getPullRequests() != null) {
                data.set("pullRequests", om.valueToTree(this.getPullRequests()));
            }
            if (this.getPullRequestsFromForks() != null) {
                data.set("pullRequestsFromForks", om.valueToTree(this.getPullRequestsFromForks()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("projen.GitpodPrebuilds"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            GitpodPrebuilds.Jsii$Proxy that = (GitpodPrebuilds.Jsii$Proxy) o;

            if (this.addBadge != null ? !this.addBadge.equals(that.addBadge) : that.addBadge != null) return false;
            if (this.addCheck != null ? !this.addCheck.equals(that.addCheck) : that.addCheck != null) return false;
            if (this.addComment != null ? !this.addComment.equals(that.addComment) : that.addComment != null) return false;
            if (this.addLabel != null ? !this.addLabel.equals(that.addLabel) : that.addLabel != null) return false;
            if (this.branches != null ? !this.branches.equals(that.branches) : that.branches != null) return false;
            if (this.master != null ? !this.master.equals(that.master) : that.master != null) return false;
            if (this.pullRequests != null ? !this.pullRequests.equals(that.pullRequests) : that.pullRequests != null) return false;
            return this.pullRequestsFromForks != null ? this.pullRequestsFromForks.equals(that.pullRequestsFromForks) : that.pullRequestsFromForks == null;
        }

        @Override
        public final int hashCode() {
            int result = this.addBadge != null ? this.addBadge.hashCode() : 0;
            result = 31 * result + (this.addCheck != null ? this.addCheck.hashCode() : 0);
            result = 31 * result + (this.addComment != null ? this.addComment.hashCode() : 0);
            result = 31 * result + (this.addLabel != null ? this.addLabel.hashCode() : 0);
            result = 31 * result + (this.branches != null ? this.branches.hashCode() : 0);
            result = 31 * result + (this.master != null ? this.master.hashCode() : 0);
            result = 31 * result + (this.pullRequests != null ? this.pullRequests.hashCode() : 0);
            result = 31 * result + (this.pullRequestsFromForks != null ? this.pullRequestsFromForks.hashCode() : 0);
            return result;
        }
    }
}

==> projen-0.79.0-sources.jar: io/github/cdklabs/projen/GitpodPrebuilds.java <==
package io.github.cdklabs.projen;

/**
 * (experimental) Configure the Gitpod App for prebuilds.
 * <p>
 * Currently only GitHub is supported.
 * <p>
 * @see <a href="https://www.gitpod.io/docs/prebuilds/">https://www.gitpod.io/docs/prebuilds/</a>
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.94.0 (build b380f01)", date = "2024-01-10T23:18:45.102Z")
@software.amazon.jsii.Jsii(module = io.github.cdklabs.projen.$Module.class, fqn = "projen.GitpodPrebuilds")
@software.amazon.jsii.Jsii.Proxy(GitpodPrebuilds.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
public interface GitpodPrebuilds extends software.amazon.jsii.JsiiSerializable {

    /**
     * (experimental) Add a "Review in Gitpod" button to the pull request's description.
     * <p>
     * Default: false
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    default @org.jetbrains.annotations.Nullable java.lang.Boolean getAddBadge() {
        return null;
    }

    /**
     * (experimental) Add a check to pull requests.
     * <p>
     * Default: true
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    default @org.jetbrains.annotations.Nullable java.lang.Boolean getAddCheck() {
        return null;
    }

    /**
     * (experimental) Add a "Review in Gitpod" button as a comment to pull requests.
     * <p>
     * Default: false
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    default @org.jetbrains.annotations.Nullable java.lang.Boolean getAddComment() {
        return null;
    }

    /**
     * (experimental) Add a label once the prebuild is ready to pull requests.
     * <p>
     * Default: false
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    default @org.jetbrains.annotations.Nullable java.lang.Boolean getAddLabel() {
        return null;
    }

    /**
     * (experimental) Enable for all branches in this repo.
     * <p>
     * Default: false
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    default @org.jetbrains.annotations.Nullable java.lang.Boolean getBranches() {
        return null;
    }

    /**
     * (experimental) Enable for the master/default branch.
     * <p>
     * Default: true
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    default @org.jetbrains.annotations.Nullable java.lang.Boolean getMaster() {
        return null;
    }

    /**
     * (experimental) Enable for pull requests coming from this repo.
     * <p>
     * Default: true
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    default @org.jetbrains.annotations.Nullable java.lang.Boolean getPullRequests() {
        return null;
    }

    /**
     * (experimental) Enable for pull requests coming from forks.
     * <p>
     * Default: false
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    default @org.jetbrains.annotations.Nullable java.lang.Boolean getPullRequestsFromForks() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link GitpodPrebuilds}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link GitpodPrebuilds}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static final class Builder implements software.amazon.jsii.Builder<GitpodPrebuilds> {
        java.lang.Boolean addBadge;
        java.lang.Boolean addCheck;
        java.lang.Boolean addComment;
        java.lang.Boolean addLabel;
        java.lang.Boolean branches;
        java.lang.Boolean master;
        java.lang.Boolean pullRequests;
        java.lang.Boolean pullRequestsFromForks;

        /**
         * Sets the value of {@link GitpodPrebuilds#getAddBadge}
         * @param addBadge Add a "Review in Gitpod" button to the pull request's description.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder addBadge(java.lang.Boolean addBadge) {
            this.addBadge = addBadge;
            return this;
        }

        /**
         * Sets the value of {@link GitpodPrebuilds#getAddCheck}
         * @param addCheck Add a check to pull requests.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder addCheck(java.lang.Boolean addCheck) {
            this.addCheck = addCheck;
            return this;
        }

        /**
         * Sets the value of {@link GitpodPrebuilds#getAddComment}
         * @param addComment Add a "Review in Gitpod" button as a comment to pull requests.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder addComment(java.lang.Boolean addComment) {
            this.addComment = addComment;
            return this;
        }

        /**
         * Sets the value of {@link GitpodPrebuilds#getAddLabel}
         * @param addLabel Add a label once the prebuild is ready to pull requests.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder addLabel(java.lang.Boolean addLabel) {
            this.addLabel = addLabel;
            return this;
        }

        /**
         * Sets the value of {@link GitpodPrebuilds#getBranches}
         * @param branches Enable for all branches in this repo.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder branches(java.lang.Boolean branches) {
            this.branches = branches;
            return this;
        }

        /**
         * Sets the value of {@link GitpodPrebuilds#getMaster}
         * @param master Enable for the master/default branch.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder master(java.lang.Boolean master) {
            this.master = master;
            return this;
        }

        /**
         * Sets the value of {@link GitpodPrebuilds#getPullRequests}
         * @param pullRequests Enable for pull requests coming from this repo.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder pullRequests(java.lang.Boolean pullRequests) {
            this.pullRequests = pullRequests;
            return this;
        }

        /**
         * Sets the value of {@link GitpodPrebuilds#getPullRequestsFromForks}
         * @param pullRequestsFromForks Enable for pull requests coming from forks.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder pullRequestsFromForks(java.lang.Boolean pullRequestsFromForks) {
            this.pullRequestsFromForks = pullRequestsFromForks;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link GitpodPrebuilds}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @Override
        public GitpodPrebuilds build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link GitpodPrebuilds}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements GitpodPrebuilds {
        private final java.lang.Boolean addBadge;
        private final java.lang.Boolean addCheck;
        private final java.lang.Boolean addComment;
        private final java.lang.Boolean addLabel;
        private final java.lang.Boolean branches;
        private final java.lang.Boolean master;
        private final java.lang.Boolean pullRequests;
        private final java.lang.Boolean pullRequestsFromForks;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.addBadge = software.amazon.jsii.Kernel.get(this, "addBadge", software.amazon.jsii.NativeType.forClass(java.lang.Boolean.class));
            this.addCheck = software.amazon.jsii.Kernel.get(this, "addCheck", software.amazon.jsii.NativeType.forClass(java.lang.Boolean.class));
            this.addComment = software.amazon.jsii.Kernel.get(this, "addComment", software.amazon.jsii.NativeType.forClass(java.lang.Boolean.class));
            this.addLabel = software.amazon.jsii.Kernel.get(this, "addLabel", software.amazon.jsii.NativeType.forClass(java.lang.Boolean.class));
            this.branches = software.amazon.jsii.Kernel.get(this, "branches", software.amazon.jsii.NativeType.forClass(java.lang.Boolean.class));
            this.master = software.amazon.jsii.Kernel.get(this, "master", software.amazon.jsii.NativeType.forClass(java.lang.Boolean.class));
            this.pullRequests = software.amazon.jsii.Kernel.get(this, "pullRequests", software.amazon.jsii.NativeType.forClass(java.lang.Boolean.class));
            this.pullRequestsFromForks = software.amazon.jsii.Kernel.get(this, "pullRequestsFromForks", software.amazon.jsii.NativeType.forClass(java.lang.Boolean.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.addBadge = builder.addBadge;
            this.addCheck = builder.addCheck;
            this.addComment = builder.addComment;
            this.addLabel = builder.addLabel;
            this.branches = builder.branches;
            this.master = builder.master;
            this.pullRequests = builder.pullRequests;
            this.pullRequestsFromForks = builder.pullRequestsFromForks;
        }

        @Override
        public final java.lang.Boolean getAddBadge() {
            return this.addBadge;
        }

        @Override
        public final java.lang.Boolean getAddCheck() {
            return this.addCheck;
        }

        @Override
        public final java.lang.Boolean getAddComment() {
            return this.addComment;
        }

        @Override
        public final java.lang.Boolean getAddLabel() {
            return this.addLabel;
        }

        @Override
        public final java.lang.Boolean getBranches() {
            return this.branches;
        }

        @Override
        public final java.lang.Boolean getMaster() {
            return this.master;
        }

        @Override
        public final java.lang.Boolean getPullRequests() {
            return this.pullRequests;
        }

        @Override
        public final java.lang.Boolean getPullRequestsFromForks() {
            return this.pullRequestsFromForks;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            if (this.getAddBadge() != null) {
                data.set("addBadge", om.valueToTree(this.getAddBadge()));
            }
            if (this.getAddCheck() != null) {
                data.set("addCheck", om.valueToTree(this.getAddCheck()));
            }
            if (this.getAddComment() != null) {
                data.set("addComment", om.valueToTree(this.getAddComment()));
            }
            if (this.getAddLabel() != null) {
                data.set("addLabel", om.valueToTree(this.getAddLabel()));
            }
            if (this.getBranches() != null) {
                data.set("branches", om.valueToTree(this.getBranches()));
            }
            if (this.getMaster() != null) {
                data.set("master", om.valueToTree(this.getMaster()));
            }
            if (this.getPullRequests() != null) {
                data.set("pullRequests", om.valueToTree(this.getPullRequests()));
            }
            if (this.getPullRequestsFromForks() != null) {
                data.set("pullRequestsFromForks", om.valueToTree(this.getPullRequestsFromForks()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("projen.GitpodPrebuilds"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            GitpodPrebuilds.Jsii$Proxy that = (GitpodPrebuilds.Jsii$Proxy) o;

            if (this.addBadge != null ? !this.addBadge.equals(that.addBadge) : that.addBadge != null) return false;
            if (this.addCheck != null ? !this.addCheck.equals(that.addCheck) : that.addCheck != null) return false;
            if (this.addComment != null ? !this.addComment.equals(that.addComment) : that.addComment != null) return false;
            if (this.addLabel != null ? !this.addLabel.equals(that.addLabel) : that.addLabel != null) return false;
            if (this.branches != null ? !this.branches.equals(that.branches) : that.branches != null) return false;
            if (this.master != null ? !this.master.equals(that.master) : that.master != null) return false;
            if (this.pullRequests != null ? !this.pullRequests.equals(that.pullRequests) : that.pullRequests != null) return false;
            return this.pullRequestsFromForks != null ? this.pullRequestsFromForks.equals(that.pullRequestsFromForks) : that.pullRequestsFromForks == null;
        }

        @Override
        public final int hashCode() {
            int result = this.addBadge != null ? this.addBadge.hashCode() : 0;
            result = 31 * result + (this.addCheck != null ? this.addCheck.hashCode() : 0);
            result = 31 * result + (this.addComment != null ? this.addComment.hashCode() : 0);
            result = 31 * result + (this.addLabel != null ? this.addLabel.hashCode() : 0);
            result = 31 * result + (this.branches != null ? this.branches.hashCode() : 0);
            result = 31 * result + (this.master != null ? this.master.hashCode() : 0);
            result = 31 * result + (this.pullRequests != null ? this.pullRequests.hashCode() : 0);
            result = 31 * result + (this.pullRequestsFromForks != null ? this.pullRequestsFromForks.hashCode() : 0);
            return result;
        }
    }
}
